@@ -1,19 +1,19 @@
 #include <QtGui>
 
 #include <mbarcode-qt/plugininterfaces.h>
-#include <mbarcode-qt/sinkplugin.h>
-#include <mbarcode-qt/mainwindow.h>
+#include <mbarcode-qt/pluginaction.h>
+#include <mbarcode-qt/maemobarcodewindow.h>
 
 #include "qrplugin.h"
 #include "qrsink.h"
 
-QSet<SinkPlugin*> QrPlugin::getSinkPlugins() {
-    QSet<SinkPlugin*> newList;
+QSet<PluginAction*> QrPlugin::getPluginActions() {
+    QSet<PluginAction*> newList;
     newList.insert(sink);
     return newList;
 }
 
-void QrPlugin::initInterface(MainWindow *parent) {
+void QrPlugin::initInterface(QWidget *parent) {
     sink = new QrSink(this);
     connect(parent, SIGNAL(barcodeAnalysedSignal(QString,QString)),
             sink, SLOT(barcodeAnalysed(QString,QString)));
