@@ -7,8 +7,8 @@
 
 #include <mbarcode-qt/plugininterfaces.h>
 
-class SinkPlugin;
-class MainWindow;
+class PluginAction;
+class MaemoBarcodeWindow;
 class QrSink;
 
 class QrPlugin : public QObject, public PluginInterface
@@ -16,11 +16,11 @@ class QrPlugin : public QObject, public PluginInterface
     Q_OBJECT
     Q_INTERFACES(PluginInterface)
 public:
-    void initInterface(MainWindow *parent);
-    QSet<SinkPlugin*> getSinkPlugins();
+    void initInterface(QWidget *parent);
+    QSet<PluginAction*> getPluginActions();
     QString getName() {return "QR-Code opener";}
 private:
-    MainWindow *parent;
+    MaemoBarcodeWindow *parent;
     QString url;
     QrSink *sink;
 };
