@@ -313,14 +313,6 @@ void QrSink::barcodeAnalysed(QString barcodeType, QString barcodeData) {
 }
 
 
-
-/*
- install:c:catalogue,names,with,comma,seps;p:package,names,with,comma,seps;d:
-
-
-
- */
-
 void QrSink::openApt(QString data)
 {
     if (data.indexOf("apt:") == 0) {
